@@ -18,41 +18,43 @@ sub new {
         
     (exists $options{options} && ref $options{options} eq 'HASH')
         || confess "You must pass a hash of options"; 
-        
-    (blessed $options{meta_instance} && $options{meta_instance}->isa('Class::MOP::Instance'))
-        || confess "You must supply a meta-instance";        
-    
-    (exists $options{attributes} && ref $options{attributes} eq 'ARRAY')
-        || confess "You must pass an array of options";        
-        
-    (blessed($_) && $_->isa('Class::MOP::Attribute'))
-        || confess "You must supply a list of attributes which is a 'Class::MOP::Attribute' instance"
-            for @{$options{attributes}};    
     
     my $self = bless {
         # from our superclass
-        body          => undef,
+        '&!body'          => undef,
         # specific to this subclass
-        options       => $options{options},
-        meta_instance => $options{meta_instance},
-        attributes    => $options{attributes},        
+        '%!options'       => $options{options},
+        '$!meta_instance' => $options{metaclass}->get_meta_instance,
+        '@!attributes'    => [ $options{metaclass}->compute_all_applicable_attributes ], 
+        # ...
+        '$!associated_metaclass' => $options{metaclass},
     } => $class;
 
     # we don't want this creating 
     # a cycle in the code, if not 
     # needed
-    weaken($self->{meta_instance});
+    weaken($self->{'$!associated_metaclass'});    
 
     $self->intialize_body;
 
     return $self;    
 }
 
+## predicates
+
+# NOTE:
+# if it is blessed into this class, 
+# then it is always inlined, that is 
+# pretty much what this class is for.
+sub is_inline { 1 }
+
 ## accessors 
 
-sub options       { (shift)->{options}       }
-sub meta_instance { (shift)->{meta_instance} }
-sub attributes    { (shift)->{attributes}    }
+sub options       { (shift)->{'%!options'}       }
+sub meta_instance { (shift)->{'$!meta_instance'} }
+sub attributes    { (shift)->{'@!attributes'}    }
+
+sub associated_metaclass { (shift)->{'$!associated_metaclass'} }
 
 ## method
 
@@ -85,7 +87,7 @@ sub intialize_body {
         $code = eval $source;
         confess "Could not eval the constructor :\n\n$source\n\nbecause :\n\n$@" if $@;
     }
-    $self->{body} = $code;
+    $self->{'&!body'} = $code;
 }
 
 sub _generate_slot_initializer {
@@ -134,22 +136,56 @@ Class::MOP::Method::Constructor - Method Meta Object for constructors
 
 =head1 SYNOPSIS
 
+  use Class::MOP::Method::Constructor;
+  
+  my $constructor = Class::MOP::Method::Constructor->new(
+      metaclass => $metaclass,       
+      options   => {
+          debug => 1, # this is all for now
+      },                        
+  );
+  
+  # calling the constructor ...
+  $constructor->body->($metaclass->name, %params);
+  
 =head1 DESCRIPTION
 
+This is a subclass of C<Class::MOP::Method> which deals with 
+class constructors.  
+
 =head1 METHODS
 
 =over 4
 
-=item B<new>
-
-=item B<attributes>
-
-=item B<meta_instance>
+=item B<new (metaclass => $meta, options => \%options)>
 
 =item B<options>
 
+This returns the options HASH which is passed into C<new>.
+
+=item B<associated_metaclass>
+
+This returns the metaclass which is passed into C<new>.
+
+=item B<attributes>
+
+This returns the list of attributes which are associated with the 
+metaclass which is passed into C<new>.
+
+=item B<meta_instance>
+
+This returns the meta instance which is associated with the 
+metaclass which is passed into C<new>.
+
+=item B<is_inline>
+
+This returns a boolean, but since constructors are very rarely 
+not inlined, this always returns true for now.
+
 =item B<intialize_body>
 
+This creates the code reference for the constructor itself. 
+
 =back
 
 =head1 AUTHORS
@@ -158,7 +194,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Infinity Interactive, Inc.
+Copyright 2006, 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
